@@ -40,10 +40,10 @@ DebugOutputTextEdit::~DebugOutputTextEdit()
 TQPopupMenu* DebugOutputTextEdit::createPopupMenu(const TQPoint &)
 {
 	popup = new TQPopupMenu(this);
-	popup->insertItem(i18n("Cut Content"), this, TQT_SLOT(cut() ) );
- 	popup->insertItem(i18n("Copy Content"), this, TQT_SLOT(copy() ) );
+	popup->insertItem(i18n("Cut Content"), this, TQ_SLOT(cut() ) );
+ 	popup->insertItem(i18n("Copy Content"), this, TQ_SLOT(copy() ) );
 	popup->insertSeparator();
-	popup->insertItem(i18n("Clear Log Window"), this, TQT_SLOT(clear() ) );
+	popup->insertItem(i18n("Clear Log Window"), this, TQ_SLOT(clear() ) );
   popup->insertSeparator();
 
 	return popup;
