@@ -17,7 +17,7 @@
 #include <tqhbox.h>
 
 #include <tdeglobal.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdelocale.h>
 #include <kdebug.h>
 #include <tdeaboutdata.h>
