@@ -37,12 +37,11 @@
 #include <tqpoint.h>
 #include <tqsize.h>
 #include <tqpopupmenu.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdemainwindow.h>
 #include <tdeaction.h>
 #include <kprocess.h>
 #include <kwizard.h>
-#include <kapp.h>
 #include <kprocess.h>
 #include <knotifyclient.h>
 #include <knotifydialog.h>
