@@ -35,7 +35,7 @@ KVpncKicker::KVpncKicker( KVpncConfig *GlobalConfig,TQWidget* parent, const char
 	     TDEAction *quit = actionCollection()->action( "file_quit" );
         quit->disconnect();
         KVpnc *myParent = static_cast<KVpnc *>( parent );
-    connect( quit, TQT_SIGNAL( activated() ), myParent, TQT_SLOT( quitCalledKicker() ) );
+    connect( quit, TQ_SIGNAL( activated() ), myParent, TQ_SLOT( quitCalledKicker() ) );
 
 	show();
 }
