@@ -25,7 +25,7 @@
 #include <tqstring.h>
 #include <tqcursor.h>
 #include <kiconloader.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <ktextbrowser.h>
 #include <knuminput.h>
 #include <kpushbutton.h>
@@ -194,26 +194,26 @@ void LogViewerDialog::showLogPart(int start,int count, bool parseLogType)
 		{
 			if (parseLogType)
 			{
-				if (line.find(i18n("Info:"),0, FALSE) > -1 )
+				if (line.find(i18n("Info:"),0, false) > -1 )
 				{
 					type = KVpncConfig::info;
 				}
-				else if (line.find(i18n("Debug:"),0, FALSE) > -1 )
+				else if (line.find(i18n("Debug:"),0, false) > -1 )
 				{
 					type = KVpncConfig::debug;
 				}
 				// 			else
-				// 			if (line.find("remote",0, FALSE) > -1 )
+				// 			if (line.find("remote",0, false) > -1 )
 				// 			{
 				// 				type = KVpncConfig::remote;
 				// 			}
 				else
-					if (line.find(i18n("Error:"),0, FALSE) > -1 )
+					if (line.find(i18n("Error:"),0, false) > -1 )
 					{
 						type = KVpncConfig::error;
 					}
 				// 			else
-				// 			if (line.find("success",0, FALSE) > -1 )
+				// 			if (line.find("success",0, false) > -1 )
 				// 			{
 				// 				type = KVpncConfig::success;
 				// 			}
