@@ -61,7 +61,7 @@ NewProfileDialog::NewProfileDialog( TQApplication *app,TQWidget *parent, const T
 	connect( main->ImportPcfProfilePushButton , TQ_SIGNAL( clicked () ), this, TQ_SLOT( importPcfFileClicked() ) );
 	connect( main->GroupPasswordEdit, TQ_SIGNAL( textChanged(const TQString&) ), this, TQ_SLOT( groupPasswordContentChanged() ) );
 	connect( main->PasswordEdit, TQ_SIGNAL( textChanged(const TQString&) ), this, TQ_SLOT( passwordContentChanged() ) );
-	newProfileCreated = FALSE;
+	newProfileCreated = false;
 	Name = "";
 
 	// currently static for new profile
@@ -133,7 +133,7 @@ NewProfileDialog::NewProfileDialog( TQApplication *app,TQWidget *parent, const T
 	{
 		main->NetworkDeviceComboBox->insertItem( TQString( *it ) );
 	}
-	main->NetworkDeviceComboBox->setEnabled( TRUE );
+	main->NetworkDeviceComboBox->setEnabled( true );
 	main->NetworkDeviceComboBox->setCurrentText( "default" );
 
 	main->certpathURLRequester->setURL( "/etc/racoon/certs" );
@@ -157,7 +157,7 @@ NewProfileDialog::~NewProfileDialog()
 
 void NewProfileDialog::accept()
 {
-	bool canSave = TRUE;
+	bool canSave = true;
 	if ( main->ConnectionTypeComboBox->currentItem() == 0 ) {
 		profileData->setConnectionType( VpnAccountData::cisco );
 		UdpPort=10000;
@@ -192,7 +192,7 @@ void NewProfileDialog::accept()
 	else
 		profileData->setConnectionType( VpnAccountData::other );
 
-	bool validAddr = TRUE;
+	bool validAddr = true;
 
 	if ( profileData->getConnectionType() != VpnAccountData::cisco && profileData->getConnectionType() != VpnAccountData::openvpn )
 	{
@@ -200,7 +200,7 @@ void NewProfileDialog::accept()
 		{
 			KMessageBox::error ( this, i18n( "No IP address for remote network entered!" ), i18n( "No IP Address" ) );
 			GlobalConfig->appendLogEntry(  i18n( "No IP address for remote network entered!" ),GlobalConfig->error);
-			validAddr = canSave = FALSE;
+			validAddr = canSave = false;
 		}
 		else
 		{
@@ -210,7 +210,7 @@ void NewProfileDialog::accept()
 				KMessageBox::error ( this, i18n( "IP address of remote network is not valid!" ), i18n( "Invalid IP Address" ) );
 				GlobalConfig->appendLogEntry( i18n( "IP address of remote network not valid!" ) ,GlobalConfig->error);
 
-				validAddr = canSave = FALSE;
+				validAddr = canSave = false;
 			}
 			if ( validAddr )
 			{
@@ -260,7 +260,7 @@ void NewProfileDialog::accept()
 	if ( canSave )
 	{
 
-		bool nameOk = TRUE;
+		bool nameOk = true;
 		Name = main->ProfileLineEdit->text();
 
 		if (Name.contains(' '))
@@ -268,7 +268,7 @@ void NewProfileDialog::accept()
 			KMessageBox::error ( this, i18n( "Profile name can not contain spaces!" ), i18n( "Spaces Not Allowed" ) );
 			GlobalConfig->appendLogEntry( i18n( "Profile name can not contain spaces!" ) ,GlobalConfig->error);
 
-			nameOk = FALSE;
+			nameOk = false;
 		}
 
 		if (Name.isEmpty())
@@ -276,7 +276,7 @@ void NewProfileDialog::accept()
 			KMessageBox::error ( this, i18n( "Profile name can not be empty!" ), i18n( "No Name Entered" ) );
 			GlobalConfig->appendLogEntry( i18n( "Profile name can not be empty!" ) ,GlobalConfig->error);
 
-			nameOk = FALSE;
+			nameOk = false;
 		}
 
 		VpnAccountData * it;
@@ -287,7 +287,7 @@ void NewProfileDialog::accept()
 				KMessageBox::error ( this, i18n( "Profile name already exists!" ), i18n( "Name Already Exists" ) );
 				GlobalConfig->appendLogEntry(i18n( "Profile name already exists!" ) ,GlobalConfig->error);
 
-				nameOk = FALSE;
+				nameOk = false;
 				break;
 			}
 		}
@@ -296,7 +296,7 @@ void NewProfileDialog::accept()
 		{
 			profileData->setName(Name);
 			GlobalConfig->AccountList->append( profileData );
-			newProfileCreated = TRUE;
+			newProfileCreated = true;
 			TQDialog::accept();
 		}
 
@@ -317,8 +317,8 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 {
 
 	// First we should set a type
-	//buttonOk->setEnabled( FALSE );
-	main->AdvancedSettingsPushButton->setEnabled( FALSE );
+	//buttonOk->setEnabled( false );
+	main->AdvancedSettingsPushButton->setEnabled( false );
 
 	int item = main->ConnectionTypeComboBox->currentItem();
 
@@ -330,41 +330,41 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		profileData->setConnectionType( VpnAccountData::cisco );
 
-		main->CheckGroupPass->setEnabled( TRUE );
-		main->CheckUserPass->setEnabled( TRUE );
+		main->CheckGroupPass->setEnabled( true );
+		main->CheckUserPass->setEnabled( true );
 
-		main->IDLineEdit->setEnabled( TRUE );
-		main->LabelID->setEnabled( TRUE );
+		main->IDLineEdit->setEnabled( true );
+		main->LabelID->setEnabled( true );
 
-		main->UsernameLineEdit->setEnabled( TRUE );
-		main->LabelUsername->setEnabled( TRUE );
+		main->UsernameLineEdit->setEnabled( true );
+		main->LabelUsername->setEnabled( true );
 
-		main->PasswordEdit->setEnabled( TRUE );
-		main->LabelPassword->setEnabled( TRUE );
+		main->PasswordEdit->setEnabled( true );
+		main->LabelPassword->setEnabled( true );
 
-		main->AdvancedSettingsPushButton->setEnabled( TRUE );
+		main->AdvancedSettingsPushButton->setEnabled( true );
 
-		main->x509certURLRequester->setEnabled( FALSE );
-		main->LabelCertificate->setEnabled( FALSE );
+		main->x509certURLRequester->setEnabled( false );
+		main->LabelCertificate->setEnabled( false );
 
-		main->certpathURLRequester->setEnabled( FALSE );
-		main->LabelCertificatePath->setEnabled( FALSE );
+		main->certpathURLRequester->setEnabled( false );
+		main->LabelCertificatePath->setEnabled( false );
 
-		main->NetworkDeviceComboBox->setEnabled( FALSE );
-		main->LabelNetworkDevice->setEnabled( FALSE );
-		main->AuthTypeComboBox->setEnabled( FALSE );
-		main->LabelAuthType->setEnabled( FALSE );
+		main->NetworkDeviceComboBox->setEnabled( false );
+		main->LabelNetworkDevice->setEnabled( false );
+		main->AuthTypeComboBox->setEnabled( false );
+		main->LabelAuthType->setEnabled( false );
 
-		main->PSKLineEdit->setEnabled( FALSE );
-		main->LabelPsk->setEnabled( FALSE );
+		main->PSKLineEdit->setEnabled( false );
+		main->LabelPsk->setEnabled( false );
 
-		//buttonCancel->setEnabled( TRUE );
-		//buttonOk->setEnabled( TRUE );
+		//buttonCancel->setEnabled( true );
+		//buttonOk->setEnabled( true );
 
-		main->RemoteNetAddrLineEdit->setEnabled( FALSE );
-		main->LabelRemoteNetwork->setEnabled( FALSE );
+		main->RemoteNetAddrLineEdit->setEnabled( false );
+		main->LabelRemoteNetwork->setEnabled( false );
 
-		main->RemoteNetMaskComboBox->setEnabled( FALSE );
+		main->RemoteNetMaskComboBox->setEnabled( false );
 
 	} // vpnc
 
@@ -380,44 +380,44 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		profileData->setConnectionType( VpnAccountData::racoon );
 
-		main->x509certURLRequester->setEnabled( TRUE );
-		main->LabelCertificate->setEnabled( TRUE );
+		main->x509certURLRequester->setEnabled( true );
+		main->LabelCertificate->setEnabled( true );
 
-		main->certpathURLRequester->setEnabled( TRUE );
-		main->LabelCertificatePath->setEnabled( TRUE );
+		main->certpathURLRequester->setEnabled( true );
+		main->LabelCertificatePath->setEnabled( true );
 
-		main->NetworkDeviceComboBox->setEnabled ( TRUE );
-		main->LabelNetworkDevice->setEnabled( TRUE );
+		main->NetworkDeviceComboBox->setEnabled ( true );
+		main->LabelNetworkDevice->setEnabled( true );
 
-		main->AuthTypeComboBox->setEnabled( TRUE );
-		main->LabelAuthType->setEnabled( TRUE );
+		main->AuthTypeComboBox->setEnabled( true );
+		main->LabelAuthType->setEnabled( true );
 
-		main->PSKLineEdit->setEnabled( TRUE );
-		main->LabelPsk->setEnabled( TRUE );
+		main->PSKLineEdit->setEnabled( true );
+		main->LabelPsk->setEnabled( true );
 
-		main->RemoteNetAddrLineEdit->setEnabled( TRUE );
-		main->LabelRemoteNetwork->setEnabled( TRUE );
+		main->RemoteNetAddrLineEdit->setEnabled( true );
+		main->LabelRemoteNetwork->setEnabled( true );
 
-		main->RemoteNetMaskComboBox->setEnabled( TRUE );
+		main->RemoteNetMaskComboBox->setEnabled( true );
 
-		main->PasswordEdit->setEnabled( FALSE );
-		main->LabelPassword->setEnabled( FALSE );
+		main->PasswordEdit->setEnabled( false );
+		main->LabelPassword->setEnabled( false );
 
-		main->CheckGroupPass->setEnabled( FALSE );
-		main->CheckUserPass->setEnabled( FALSE );
+		main->CheckGroupPass->setEnabled( false );
+		main->CheckUserPass->setEnabled( false );
 
-		main->IDLineEdit->setEnabled( FALSE );
-		main->LabelID->setEnabled( FALSE );
+		main->IDLineEdit->setEnabled( false );
+		main->LabelID->setEnabled( false );
 
-		main->UsernameLineEdit->setEnabled( FALSE );
-		main->LabelUsername->setEnabled( FALSE );
+		main->UsernameLineEdit->setEnabled( false );
+		main->LabelUsername->setEnabled( false );
 
-		main->GroupPasswordEdit->setEnabled( FALSE );
-		main->LabelGroupPassword->setEnabled( FALSE );
+		main->GroupPasswordEdit->setEnabled( false );
+		main->LabelGroupPassword->setEnabled( false );
 
-		//buttonCancel->setEnabled( TRUE );
-		//buttonOk->setEnabled( TRUE );
-		main->AdvancedSettingsPushButton->setEnabled( TRUE );
+		//buttonCancel->setEnabled( true );
+		//buttonOk->setEnabled( true );
+		main->AdvancedSettingsPushButton->setEnabled( true );
 	} // racoon
 
 	else if ( item == VpnAccountData::ConnectionType(VpnAccountData::freeswan) )
@@ -432,44 +432,44 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		profileData->setConnectionType( VpnAccountData::freeswan );
 
-		main->x509certURLRequester->setEnabled( TRUE );
-		main->LabelCertificate->setEnabled( TRUE );
+		main->x509certURLRequester->setEnabled( true );
+		main->LabelCertificate->setEnabled( true );
 
-		main->certpathURLRequester->setEnabled( TRUE );
-		main->LabelCertificatePath->setEnabled( TRUE );
+		main->certpathURLRequester->setEnabled( true );
+		main->LabelCertificatePath->setEnabled( true );
 
-		main->NetworkDeviceComboBox->setEnabled ( TRUE );
-		main->LabelNetworkDevice->setEnabled( TRUE );
+		main->NetworkDeviceComboBox->setEnabled ( true );
+		main->LabelNetworkDevice->setEnabled( true );
 
-		main->AuthTypeComboBox->setEnabled( TRUE );
-		main->LabelAuthType->setEnabled( TRUE );
+		main->AuthTypeComboBox->setEnabled( true );
+		main->LabelAuthType->setEnabled( true );
 
-		main->PSKLineEdit->setEnabled( TRUE );
-		main->LabelPsk->setEnabled( TRUE );
+		main->PSKLineEdit->setEnabled( true );
+		main->LabelPsk->setEnabled( true );
 
-		main->RemoteNetAddrLineEdit->setEnabled( TRUE );
-		main->LabelRemoteNetwork->setEnabled( TRUE );
+		main->RemoteNetAddrLineEdit->setEnabled( true );
+		main->LabelRemoteNetwork->setEnabled( true );
 
-		main->RemoteNetMaskComboBox->setEnabled( TRUE );
+		main->RemoteNetMaskComboBox->setEnabled( true );
 
-		main->CheckGroupPass->setEnabled( FALSE );
-		main->CheckUserPass->setEnabled( FALSE );
+		main->CheckGroupPass->setEnabled( false );
+		main->CheckUserPass->setEnabled( false );
 
-		main->IDLineEdit->setEnabled( FALSE );
-		main->LabelID->setEnabled( FALSE );
+		main->IDLineEdit->setEnabled( false );
+		main->LabelID->setEnabled( false );
 
-		main->PasswordEdit->setEnabled( FALSE );
-		main->LabelPassword->setEnabled( FALSE );
+		main->PasswordEdit->setEnabled( false );
+		main->LabelPassword->setEnabled( false );
 
-		main->UsernameLineEdit->setEnabled( FALSE );
-		main->LabelUsername->setEnabled( FALSE );
+		main->UsernameLineEdit->setEnabled( false );
+		main->LabelUsername->setEnabled( false );
 
-		main->GroupPasswordEdit->setEnabled( FALSE );
-		main->LabelGroupPassword->setEnabled( FALSE );
+		main->GroupPasswordEdit->setEnabled( false );
+		main->LabelGroupPassword->setEnabled( false );
 
-		//		buttonCancel->setEnabled( TRUE );
-		//		buttonOk->setEnabled( TRUE );
-		main->AdvancedSettingsPushButton->setEnabled( TRUE );
+		//		buttonCancel->setEnabled( true );
+		//		buttonOk->setEnabled( true );
+		main->AdvancedSettingsPushButton->setEnabled( true );
 	} // freeswan
 
 	else if ( item == VpnAccountData::ConnectionType(VpnAccountData::pptp) )
@@ -484,44 +484,44 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		profileData->setConnectionType( VpnAccountData::pptp );
 
-		main->x509certURLRequester->setEnabled( FALSE );
-		main->LabelCertificate->setEnabled( FALSE );
+		main->x509certURLRequester->setEnabled( false );
+		main->LabelCertificate->setEnabled( false );
 
-		main->certpathURLRequester->setEnabled( FALSE );
-		main->LabelCertificatePath->setEnabled( FALSE );
+		main->certpathURLRequester->setEnabled( false );
+		main->LabelCertificatePath->setEnabled( false );
 
-		main->NetworkDeviceComboBox->setEnabled ( FALSE );
-		main->LabelNetworkDevice->setEnabled( FALSE );
+		main->NetworkDeviceComboBox->setEnabled ( false );
+		main->LabelNetworkDevice->setEnabled( false );
 
-		main->AuthTypeComboBox->setEnabled( FALSE );
-		main->LabelAuthType->setEnabled( FALSE );
+		main->AuthTypeComboBox->setEnabled( false );
+		main->LabelAuthType->setEnabled( false );
 
-		main->PSKLineEdit->setEnabled( FALSE );
-		main->LabelPsk->setEnabled( FALSE );
+		main->PSKLineEdit->setEnabled( false );
+		main->LabelPsk->setEnabled( false );
 
-		main->RemoteNetAddrLineEdit->setEnabled( TRUE );
-		main->LabelRemoteNetwork->setEnabled( TRUE );
+		main->RemoteNetAddrLineEdit->setEnabled( true );
+		main->LabelRemoteNetwork->setEnabled( true );
 
-		main->RemoteNetMaskComboBox->setEnabled( TRUE );
+		main->RemoteNetMaskComboBox->setEnabled( true );
 
-		main->CheckGroupPass->setEnabled( FALSE );
-		main->CheckUserPass->setEnabled( TRUE );
+		main->CheckGroupPass->setEnabled( false );
+		main->CheckUserPass->setEnabled( true );
 
-		main->IDLineEdit->setEnabled( FALSE );
-		main->LabelID->setEnabled( FALSE );
+		main->IDLineEdit->setEnabled( false );
+		main->LabelID->setEnabled( false );
 
-		main->PasswordEdit->setEnabled( TRUE );
-		main->LabelPassword->setEnabled( TRUE );
+		main->PasswordEdit->setEnabled( true );
+		main->LabelPassword->setEnabled( true );
 
-		main->UsernameLineEdit->setEnabled( TRUE );
-		main->LabelUsername->setEnabled( TRUE );
+		main->UsernameLineEdit->setEnabled( true );
+		main->LabelUsername->setEnabled( true );
 
-		main->GroupPasswordEdit->setEnabled( FALSE );
-		main->LabelGroupPassword->setEnabled( FALSE );
+		main->GroupPasswordEdit->setEnabled( false );
+		main->LabelGroupPassword->setEnabled( false );
 
-		//buttonCancel->setEnabled( TRUE );
-		//buttonOk->setEnabled( TRUE );
-		main->AdvancedSettingsPushButton->setEnabled( TRUE );
+		//buttonCancel->setEnabled( true );
+		//buttonOk->setEnabled( true );
+		main->AdvancedSettingsPushButton->setEnabled( true );
 	} // pptp
 	else if ( item == VpnAccountData::ConnectionType(VpnAccountData::openvpn) )
 	{
@@ -534,45 +534,45 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		profileData->setConnectionType( VpnAccountData::openvpn );
 
-		main->x509certURLRequester->setEnabled( TRUE );
-		main->LabelCertificate->setEnabled( TRUE );
+		main->x509certURLRequester->setEnabled( true );
+		main->LabelCertificate->setEnabled( true );
 
-		main->certpathURLRequester->setEnabled( TRUE );
-		main->LabelCertificatePath->setEnabled( TRUE );
+		main->certpathURLRequester->setEnabled( true );
+		main->LabelCertificatePath->setEnabled( true );
 
-		main->NetworkDeviceComboBox->setEnabled ( TRUE );
-		main->LabelNetworkDevice->setEnabled( TRUE );
+		main->NetworkDeviceComboBox->setEnabled ( true );
+		main->LabelNetworkDevice->setEnabled( true );
 
-		main->AuthTypeComboBox->setEnabled( TRUE );
-		main->LabelAuthType->setEnabled( TRUE );
+		main->AuthTypeComboBox->setEnabled( true );
+		main->LabelAuthType->setEnabled( true );
 
-		main->PSKLineEdit->setEnabled( TRUE );
-		main->LabelPsk->setEnabled( TRUE );
+		main->PSKLineEdit->setEnabled( true );
+		main->LabelPsk->setEnabled( true );
 
-		main->RemoteNetAddrLineEdit->setEnabled( FALSE );
-		main->LabelRemoteNetwork->setEnabled( FALSE );
+		main->RemoteNetAddrLineEdit->setEnabled( false );
+		main->LabelRemoteNetwork->setEnabled( false );
 
-		main->RemoteNetMaskComboBox->setEnabled( TRUE );
+		main->RemoteNetMaskComboBox->setEnabled( true );
 
-		main->PasswordEdit->setEnabled( FALSE );
-		main->LabelPassword->setEnabled( FALSE );
+		main->PasswordEdit->setEnabled( false );
+		main->LabelPassword->setEnabled( false );
 
-		main->CheckGroupPass->setEnabled( FALSE );
-		main->CheckUserPass->setEnabled( FALSE );
+		main->CheckGroupPass->setEnabled( false );
+		main->CheckUserPass->setEnabled( false );
 
-		main->IDLineEdit->setEnabled( FALSE );
-		main->LabelID->setEnabled( FALSE );
+		main->IDLineEdit->setEnabled( false );
+		main->LabelID->setEnabled( false );
 
 
-		main->UsernameLineEdit->setEnabled( FALSE );
-		main->LabelUsername->setEnabled( FALSE );
+		main->UsernameLineEdit->setEnabled( false );
+		main->LabelUsername->setEnabled( false );
 
-		main->GroupPasswordEdit->setEnabled( FALSE );
-		main->LabelGroupPassword->setEnabled( FALSE );
+		main->GroupPasswordEdit->setEnabled( false );
+		main->LabelGroupPassword->setEnabled( false );
 
-		//buttonCancel->setEnabled( TRUE );
-		//buttonOk->setEnabled( TRUE );
-		main->AdvancedSettingsPushButton->setEnabled( TRUE );
+		//buttonCancel->setEnabled( true );
+		//buttonOk->setEnabled( true );
+		main->AdvancedSettingsPushButton->setEnabled( true );
 	} // openvpn
 
 	// other
@@ -581,17 +581,17 @@ void NewProfileDialog::connectiontypeChanged( const TQString& )
 
 		if (GlobalConfig->KvpncDebugLevel > 0)
 			GlobalConfig->appendLogEntry( "new type: other",GlobalConfig->debug );
-		// 		main->x509certURLRequester->setEnabled( FALSE );
-		// 		main->AuthTypeComboBox->setEnabled( FALSE );
-		// 		main->PSKLineEdit->setEnabled( FALSE );
+		// 		main->x509certURLRequester->setEnabled( false );
+		// 		main->AuthTypeComboBox->setEnabled( false );
+		// 		main->PSKLineEdit->setEnabled( false );
 		//
-		// 		main->CheckGroupPass->setEnabled( FALSE );
-		// 		main->CheckUserPass->setEnabled( FALSE );
-		// 		main->IDLineEdit->setEnabled( FALSE );
-		// 		main->UsernameLineEdit->setEnabled( FALSE );
-		// 		main->AdvancedSettingsPushButton->setEnabled( FALSE );
-		//		buttonCancel->setEnabled( FALSE );
-		//buttonOk->setEnabled( FALSE );
+		// 		main->CheckGroupPass->setEnabled( false );
+		// 		main->CheckUserPass->setEnabled( false );
+		// 		main->IDLineEdit->setEnabled( false );
+		// 		main->UsernameLineEdit->setEnabled( false );
+		// 		main->AdvancedSettingsPushButton->setEnabled( false );
+		//		buttonCancel->setEnabled( false );
+		//buttonOk->setEnabled( false );
 	}
 }
 
@@ -600,26 +600,26 @@ void NewProfileDialog::authTypeChanged( const TQString& )
 	if ( main->AuthTypeComboBox->currentItem() == VpnAccountData::AuthenticationType(VpnAccountData::cert ))
 	{
 		// certificate
-		main->PSKLineEdit->setEnabled( FALSE );
-		main->LabelPsk->setEnabled( FALSE );
+		main->PSKLineEdit->setEnabled( false );
+		main->LabelPsk->setEnabled( false );
 
-		main->x509certURLRequester->setEnabled( TRUE );
-		main->LabelCertificate->setEnabled( TRUE );
+		main->x509certURLRequester->setEnabled( true );
+		main->LabelCertificate->setEnabled( true );
 
-		main->certpathURLRequester->setEnabled( TRUE );
-		main->LabelCertificatePath->setEnabled( TRUE );
+		main->certpathURLRequester->setEnabled( true );
+		main->LabelCertificatePath->setEnabled( true );
 	}
 	if ( main->AuthTypeComboBox->currentItem() == VpnAccountData::AuthenticationType(VpnAccountData::psk ))
 	{
 		// psk
-		main->PSKLineEdit->setEnabled( TRUE );
-		main->LabelPsk->setEnabled( TRUE );
+		main->PSKLineEdit->setEnabled( true );
+		main->LabelPsk->setEnabled( true );
 
-		main->x509certURLRequester->setEnabled( FALSE );
-		main->LabelCertificate->setEnabled( FALSE );
+		main->x509certURLRequester->setEnabled( false );
+		main->LabelCertificate->setEnabled( false );
 
-		main->certpathURLRequester->setEnabled( FALSE );
-		main->LabelCertificatePath->setEnabled( FALSE );
+		main->certpathURLRequester->setEnabled( false );
+		main->LabelCertificatePath->setEnabled( false );
 	}
 
 }
@@ -633,9 +633,9 @@ void NewProfileDialog::profileNameChanged( const TQString& )
 {
 	// 	LogOutput->append ( "text changed!" );
 	// 	if ( main->ProfileLineEdit->text().isEmpty() )
-	// 		buttonOk->setEnabled( FALSE );
+	// 		buttonOk->setEnabled( false );
 	// 	else
-	// 		buttonOk->setEnabled( TRUE );
+	// 		buttonOk->setEnabled( true );
 }
 
 TQString NewProfileDialog::getName()
