@@ -40,11 +40,11 @@ void ProfileNetworkNatOptions::useNatToggled(bool)
 {
 	if (UseNatCheckbox->isChecked())
 	{
-		UdpPortCheckbox->setEnabled(TRUE);
+		UdpPortCheckbox->setEnabled(true);
 	}
 	else
 	{
-		UdpPortCheckbox->setEnabled(FALSE);
+		UdpPortCheckbox->setEnabled(false);
 	}
 }
 
@@ -53,11 +53,11 @@ void ProfileNetworkNatOptions::udpPortToggled(bool)
 {
 	if (UdpPortCheckbox->isChecked())
 	{
-		UdpPortSpinbox->setEnabled(TRUE);
+		UdpPortSpinbox->setEnabled(true);
 	}
 	else
 	{
-		UdpPortSpinbox->setEnabled(FALSE);
+		UdpPortSpinbox->setEnabled(false);
 	}
 }
 
